summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/sqlite/build.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/sqlite/build.c')
-rw-r--r--src/3rdparty/sqlite/build.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/3rdparty/sqlite/build.c b/src/3rdparty/sqlite/build.c
index 2639604b3..87c88346b 100644
--- a/src/3rdparty/sqlite/build.c
+++ b/src/3rdparty/sqlite/build.c
@@ -527,7 +527,7 @@ void sqliteStartTable(
/* Begin generating the code that will insert the table record into
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
** PRIMARY KEY or UNITQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
** now.
@@ -1462,7 +1462,7 @@ void sqliteDeferForeignKey(Parse *pParse, int isDeferred){
** Create a new index for an SQL table. pIndex is the name of the index
** and pTable is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
** UNITQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
**
@@ -1532,7 +1532,7 @@ void sqliteCreateIndex(
** index, then we will continue to process this index.
**
** If pName==0 it means that we are
** dealing with a primary key or UNITQUE constraint. We have to invent our
** own name.
*/
if( pName && !db->init.busy ){
@@ -1674,7 +1674,7 @@ void sqliteCreateIndex(
** we don't want to recreate it.
**
** If pTable==0 it means this index is generated as a primary key
** or UNITQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.
*/
@@ -1768,7 +1768,7 @@ void sqliteDropIndex(Parse *pParse, SrcList *pName){
goto exit_drop_index;
}
if( pIndex->autoIndex ){
- sqliteErrorMsg(pParse, "index associated with UNITQUE "
+ sqliteErrorMsg(pParse, "index associated with UNIQUE "
"or PRIMARY KEY constraint cannot be dropped", 0);
goto exit_drop_index;
}
@@ -527,7 +527,7 @@ void sqliteStartTable(
** the SQLITE_MASTER table. Note in particular that we must go ahead
** and allocate the record number for the table entry now. Before any
- ** PRIMARY KEY or UNITQUE keywords are parsed. Those keywords will cause
+ ** PRIMARY KEY or UNIQUE keywords are parsed. Those keywords will cause
** indices to be created and the table record must come before the
** indices. Hence, the record number for the table must be allocated
@@ -1462,7 +1462,7 @@ void sqliteDeferForeignKey(Parse *pParse, int isDeferred){
** and pTable is the name of the table that is to be indexed. Both will
** be NULL for a primary key or an index that is created to satisfy a
-** UNITQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
+** UNIQUE constraint. If pTable and pIndex are NULL, use pParse->pNewTable
** as the table to be indexed. pParse->pNewTable is a table that is
** currently being constructed by a CREATE TABLE statement.
@@ -1532,7 +1532,7 @@ void sqliteCreateIndex(
**
** If pName==0 it means that we are
- ** dealing with a primary key or UNITQUE constraint. We have to invent our
+ ** dealing with a primary key or UNIQUE constraint. We have to invent our
** own name.
*/
@@ -1674,7 +1674,7 @@ void sqliteCreateIndex(
**
** If pTable==0 it means this index is generated as a primary key
- ** or UNITQUE constraint of a CREATE TABLE statement. Since the table
+ ** or UNIQUE constraint of a CREATE TABLE statement. Since the table
** has just been created, it contains no data and the index initialization
** step can be skipped.